# UnmergeTableCellsRequest

Unmerges cells in a Table.

**Type:** object

## Properties

- **tableRange** ([TableRange](tablerange.md)): The table range specifying which cells of the table to unmerge. All merged cells in this range will be unmerged, and cells that are already unmerged will not be affected. If the range has no merged cells, the request will do nothing. If there is text in any of the merged cells, the text will remain in the "head" cell of the resulting block of unmerged cells. The "head" cell is the upper-left cell when the content direction is from left to right, and the upper-right otherwise.
